using System;
using Server.Items;

namespace Server.Engines.Craft
{
	public class DefTinkering : CraftSystem
	{
		public override SkillName MainSkill
		{
			get	{ return SkillName.Tinkering; }
		}

		public override string GumpTitle
		{
			get { return "TINKERING MENU"; }
		}

		public override int GumpTitlePos
		{
			get { return 185; }
		}

		private static CraftSystem m_CraftSystem;

		public static CraftSystem CraftSystem
		{
			get
			{
				if ( m_CraftSystem == null )
					m_CraftSystem = new DefTinkering();

				return m_CraftSystem;
			}
		}

		private DefTinkering() : base( 1, 1, 3.0 )
		{
		}

		public override bool CanCraft( Mobile from, BaseTool tool, Type itemType )
		{
			if ( tool.Deleted )
			{
				return false;
			}
			else
			{
				if ( tool.Durability < 1 )
				{
					from.SendMessage( "This tool is broken" );
					return false;
				}
			}

			return true;
		}

		public override void PlayCraftEffect( Mobile from )
		{
			from.PlaySound( 0x241 );
		}

		public override void PlayEndingEffect( Mobile from, bool failed, bool lostMaterial, bool toolBroken, int quality )
		{
			if ( toolBroken )
			{
				from.SendLocalizedMessage( 1044038 ); // You have worn out your tool
			}

			if ( failed )
			{
				if ( lostMaterial) 
				{
					from.SendLocalizedMessage( 1044043 ); // You failed to create the item, and some of your materials are lost.
				}
				else
				{
					from.SendLocalizedMessage( 1044157 ); // You failed to create the item, but no materials were lost.
				}
			}
			else
			{
				if ( quality == 0 )
					from.SendLocalizedMessage( 502785 ); // You were barely able to make the item.  It's quality is below average
				else if (quality == 2 )
					from.SendLocalizedMessage( 502784 ); // Due to your exceptional skill, its quality is higher than average
				else				
					from.SendLocalizedMessage( 1044154 ); // You create the item
			}
		}

		public override void InitCraftList()
		{
			// Wooden items
			AddCraft( typeof( JointingPlane ), "Wooden Items", "Jointing Plane", 0.0, 25.0, typeof( Log ), "Log", 4 );
			AddCraft( typeof( MouldingPlane ), "Wooden Items", "Moulding Plane", 0.0, 25.0, typeof( Log ), "Log", 4 );
			AddCraft( typeof( SmoothingPlane ), "Wooden Items", "Smoothing Plane", 0.0, 25.0, typeof( Log ), "Log", 4 );
			AddCraft( typeof( ClockFrame ), "Wooden Items", "Clock Frame", 0.0, 25.0, typeof( Log ), "Log", 6 );
			AddCraft( typeof( Axle ), "Wooden Items", "Axle", 0.0, 15.0, typeof( Log ), "Log", 2 );

			// Tools
			AddCraft( typeof( Scissors ), "Tools", "Scissors", 5.0, 20.0, typeof( IronIngot ), "Iron Ingot", 2, 1044037 );
			AddCraft( typeof( MortarPestle ), "Tools", "Mortar and Pestle", 20.0, 40.0, typeof( IronIngot ), "Iron Ingot", 3, 1044037 );
			AddCraft( typeof( Scorp ), "Tools", "Scorp", 30.0, 45.0, typeof( IronIngot ), "Iron Ingot", 2, 1044037 );
			AddCraft( typeof( TinkerTools ), "Tools", "Tinker's tools", 10.0, 20.0, typeof( IronIngot ), "Iron Ingot", 2, 1044037 );
			AddCraft( typeof( Hatchet ), "Tools", "Hatchet", 30.0, 60.0, typeof( IronIngot ), "Iron Ingot", 4, 1044037 );
			AddCraft( typeof( DrawKnife ), "Tools", "Draw Knife", 30.0, 45.0, typeof( IronIngot ), "Iron Ingot", 2, 1044037 );
			AddCraft( typeof( SewingKit ), "Tools", "Sewing Kit", 10.0, 20.0, typeof( IronIngot ), "Iron Ingot", 2, 1044037 );
			AddCraft( typeof( Saw ), "Tools", "Saw", 30.0, 60.0, typeof( IronIngot ), "Iron Ingot", 4, 1044037 );
			AddCraft( typeof( DovetailSaw ), "Tools", "Dovetail Saw", 30.0, 60.0, typeof( IronIngot ), "Iron Ingot", 4, 1044037 );
			AddCraft( typeof( Froe ), "Tools", "Froe", 30.0, 45.0, typeof( IronIngot ), "Iron Ingot", 2, 1044037 );
			AddCraft( typeof( Hammer ), "Tools", "Hammer", 30.0, 45.0, typeof( IronIngot ), "Iron Ingot", 1, 1044037 );
			AddCraft( typeof( Tongs ), "Tools", "Tongs", 35.0, 50.0, typeof( IronIngot ), "Iron Ingot", 1, 1044037 );
			AddCraft( typeof( SmithHammer ), "Tools", "Smith's Hammer", 40.0, 80.0, typeof( IronIngot ), "Iron Ingot", 4, 1044037 );
			AddCraft( typeof( Inshave ), "Tools", "Inshave", 30.0, 45.0, typeof( IronIngot ), "Iron Ingot", 2, 1044037 );
			AddCraft( typeof( Pickaxe ), "Tools", "Pickaxe", 40.0, 80.0, typeof( IronIngot ), "Iron Ingot", 4, 1044037 );
			AddCraft( typeof( Lockpick ), "Tools", "Lockpick", 45.0, 90.0, typeof( IronIngot ), "Iron Ingot", 1, 1044037 );
			AddCraft( typeof( ScribesPen ), "Tools", "Scribe's Pen", 25.0, 40.0, typeof( IronIngot ), "Iron Ingot", 1, 1044037 ); // What are the resources for this?

			// Parts
			AddCraft( typeof( Gears ), "Parts", "Gears", 5.0, 30.0, typeof( IronIngot ), "Iron Ingot", 2, 1044037 );
			AddCraft( typeof( ClockParts ), "Parts", "Clock Parts", 0.0, 25.0, typeof( IronIngot ), "Iron Ingot", 1, 1044037 );
			AddCraft( typeof( BarrelTap ), "Parts", "Barrel Tap", 35.0, 55.0, typeof( IronIngot ), "Iron Ingot", 2, 1044037 );
			AddCraft( typeof( Springs ), "Parts", "Springs", 5.0, 20.0, typeof( IronIngot ), "Iron Ingot", 2, 1044037 );
			AddCraft( typeof( SextantParts ), "Parts", "Sextant Parts", 0.0, 25.0, typeof( IronIngot ), "Iron Ingot", 4, 1044037 );
			AddCraft( typeof( BarrelHoops ), "Parts", "Barrel Hoops", 0.0, 35.0, typeof( IronIngot ), "Iron Ingot", 5, 1044037 );
			AddCraft( typeof( Hinge ), "Parts", "Hinge", 5.0, 25.0, typeof( IronIngot ), "Iron Ingot", 2, 1044037 );

			// Utensils
			AddCraft( typeof( ButcherKnife ), "Utensils", "Butcher Knife", 25.0, 50.0, typeof( IronIngot ), "Iron Ingot", 2, 1044037 );
			AddCraft( typeof( Cleaver ), "Utensils", "Cleaver", 20.0, 40.0, typeof( IronIngot ), "Iron Ingot", 3, 1044037 );
			AddCraft( typeof( SkinningKnife ), "Utensils", "Skinning Knife", 25.0, 50.0, typeof( IronIngot ), "Iron Ingot", 2, 1044037 );

			// Misc
			AddCraft( typeof( Candelabra ), "Miscellaneous", "Candelabra", 55.0, 70.0, typeof( IronIngot ), "Iron Ingot", 4, 1044037 );
			AddCraft( typeof( Scales ), "Miscellaneous", "Scales", 60.0, 75.0, typeof( IronIngot ), "Iron Ingot", 4, 1044037 );
			AddCraft( typeof( Lantern ), "Miscellaneous", "Lantern", 30.0, 45.0, typeof( IronIngot ), "Iron Ingot", 2, 1044037 );

			// Multi-Component Items
			int index = AddCraft( typeof( AxleGears ), "Multi-Component Items", "Axle with Gears", 0.0, 20.0, typeof( Axle ), "Axle", 1 );
			AddRes( index, typeof( Gears ), "Gears", 1 );

			index = AddCraft( typeof( ClockParts ), "Multi-Component Items", "Clock Parts", 0.0, 25.0, typeof( AxleGears ), "Axle and Gears", 1 );
			AddRes( index, typeof( Springs ), "Springs", 1 );

			index = AddCraft( typeof( SextantParts ), "Multi-Component Items", "Sextant Parts", 0.0, 25.0, typeof( AxleGears ), "Axle and Gears", 1 );
			AddRes( index, typeof( Hinge ), "Hinge", 1 );

			// TODO: Clock

			AddCraft( typeof( Sextant ), "Multi-Component Items", "Sextant", 0.0, 35.0, typeof( SextantParts ), "Sextant Parts", 1 );

			index = AddCraft( typeof( PotionKeg ), "Multi-Component Items", "Potion Keg", 75.0, 90.0, typeof( Keg ), "Empty Keg", 1 );
			AddRes( index, typeof( BarrelTap ), "Barrel Tap", 1 );
			AddRes( index, typeof( BarrelLid ), "Barrel Lid", 1 );
			AddRes( index, typeof( Bottle ), "Bottle", 10 );
		}
	}
}