using System;
using Server.Network;
using Server.Gumps;

namespace Server.Gumps
{
	public class GoGump : Gump
	{
		public static readonly LocationTree Felucca = new LocationTree( "felucca.xml", Map.Felucca );
		public static readonly LocationTree Trammel = new LocationTree( "trammel.xml", Map.Trammel );
		public static readonly LocationTree Ilshenar = new LocationTree( "ilshenar.xml", Map.Ilshenar );

		public static void DisplayTo( Mobile from )
		{
			LocationTree tree;

			if ( from.Map == Map.Ilshenar )
				tree = Ilshenar;
			else if ( from.Map == Map.Felucca )
				tree = Felucca;
			else
				tree = Trammel;

			if ( tree.Root != null )
				from.SendGump( new GoGump( tree, tree.Root ) );
		}

		private LocationTree m_Tree;
		private ParentNode m_Node;

		private GoGump( LocationTree tree, ParentNode node ) : base( 50, 50 )
		{
			m_Tree = tree;
			m_Node = node;

			AddPage( 0 );

			AddBackground( 0, 0, 260, 351, 5054 );

			AddImageTiled( 10, 10, 240, 23, 0x52 );
			AddImageTiled( 11, 11, 238, 21, 0xBBC );

			AddLabel( 65, 11, 0, node.Name );

			if ( node.Parent != null )
				AddButton( 13, 13, 0x15E3, 0x15E7, 1, GumpButtonType.Reply, 0 );

			AddPage( 1 );

			int page = 1;

			object[] children = node.Children;

			int index = 0;

			for ( int i = 0; i < children.Length; ++i )
			{
				if ( index >= 14 )
				{
					AddButton( 231, 13, 0x15E1, 0x15E5, 0, GumpButtonType.Page, page + 1 );

					++page;
					index = 0;

					AddPage( page );

					AddButton( 213, 13, 0x15E3, 0x15E7, 0, GumpButtonType.Page, page - 1 );
				}

				object child = children[i];

				AddImageTiled( 10, 32 + (index * 22), 240, 23, 0x52 );
				AddImageTiled( 11, 33 + (index * 22), 238, 21, 0xBBC );

				if ( child is ParentNode )
				{
					ParentNode p = (ParentNode)child;

					AddLabelCropped( 13, 33 + (index * 22), 234, 21, 0, p.Name );
					AddButton( 231, 35 + (index * 22), 0x15E1, 0x15E5, i + 2, GumpButtonType.Reply, 0 );
				}
				else if ( child is ChildNode )
				{
					ChildNode c = (ChildNode)child;

					AddLabelCropped( 13, 33 + (index * 22), 234, 21, 0, c.Name );
					AddButton( 231, 35 + (index * 22), 0x15E1, 0x15E5, i + 2, GumpButtonType.Reply, 0 );
				}

				++index;
			}
		}

		public override void OnResponse( NetState state, RelayInfo info )
		{
			Mobile from = state.Mobile;

			switch ( info.ButtonID )
			{
				case 0: // Canceled
				{
					from.SendMessage( "Go request canceled." );
					break;
				}
				case 1: // Parent
				{
					if ( m_Node.Parent != null )
						from.SendGump( new GoGump( m_Tree, m_Node.Parent ) );

					break;
				}
				default:
				{
					int index = info.ButtonID - 2;

					if ( index >= 0 && index < m_Node.Children.Length )
					{
						object o = m_Node.Children[index];

						if ( o is ParentNode )
						{
							from.SendGump( new GoGump( m_Tree, (ParentNode)o ) );
						}
						else
						{
							ChildNode n = (ChildNode)o;

							from.Map = m_Tree.Map;
							from.Location = n.Location;
						}
					}

					break;
				}
			}
		}
	}
}