using System;
using Server;
using Server.Items;

namespace Server.Misc
{
	public class RegenRates
	{
		public static void Initialize()
		{
			Mobile.DefaultHitsRate = TimeSpan.FromSeconds( 3.0 );
			Mobile.DefaultStamRate = TimeSpan.FromSeconds( 3.0 );
			Mobile.DefaultManaRate = TimeSpan.FromSeconds( 3.0 );

			Mobile.ManaRegenRateHandler = new RegenRateHandler( Mobile_ManaRegenRate );
		}

		private static TimeSpan Mobile_ManaRegenRate( Mobile from )
		{
			if ( !from.Meditating )
			{
				double n = (double)from.Mana / from.ManaMax;
				double v = Math.Sqrt( from.Skills[SkillName.Meditation].Value * 0.005 );

				n *= (1.0 - v);
				n += v;

				if ( from.Alive )
					from.CheckSkill( SkillName.Meditation, n );
			}

			double total = from.Skills[SkillName.Meditation].Value + from.Int;

			double rate;

			if ( total <= 0 )
				rate = 7.0;
			else if ( total <= 200.0 )
				rate = 7.0 - ((total / 200) * 6);
			else if ( total < 240.0 )
				rate = 1.0;
			else
				rate = 0.75;

			rate += GetArmorOffset( from );

			if ( from.Meditating )
				rate *= 0.5;

			if ( rate < 0.5 )
				rate = 0.5;
			else if ( rate > 7.0 )
				rate = 7.0;

			return TimeSpan.FromSeconds( rate );
		}

		private static double GetArmorOffset( Mobile from )
		{
			double rating = 0.0;

			rating += GetArmorMeditationValue( from.ShieldArmor as BaseArmor );
			rating += GetArmorMeditationValue( from.NeckArmor as BaseArmor );
			rating += GetArmorMeditationValue( from.HandArmor as BaseArmor );
			rating += GetArmorMeditationValue( from.HeadArmor as BaseArmor );
			rating += GetArmorMeditationValue( from.ArmsArmor as BaseArmor );
			rating += GetArmorMeditationValue( from.LegsArmor as BaseArmor );
			rating += GetArmorMeditationValue( from.ChestArmor as BaseArmor );

			return rating / 4;
		}

		private static double GetArmorMeditationValue( BaseArmor ar )
		{
			if ( ar == null )
				return 0.0;

			switch ( ar.MeditationAllowance )
			{
				default:
				case ArmorMeditationAllowance.None: return ar.ArmorRating;
				case ArmorMeditationAllowance.Half: return ar.ArmorRating / 2.0;
				case ArmorMeditationAllowance.All:  return 0.0;
			}
		}
	}
}