using System;
using Server;
using Server.Misc;
using Server.Items;
using Server.Gumps;

namespace Server.Mobiles
{
	public abstract class BaseHealer : BaseCreature
	{
		public BaseHealer() : base( AIType.AI_Mage, FightMode.Agressor, 14, 1, 0.8, 1.6 )
		{
			Hue = Utility.RandomSkinHue();

			if ( Female = Utility.RandomBool() )
			{
				Body = 0x191;
				Name = NameList.RandomFemaleName();
			}
			else
			{
				Body = 0x190;
				Name = NameList.RandomMaleName();
			}

			SetStr( 80, 100 );
			SetInt( 80, 100 );
			SetDex( 25, 50 );

			SetSkill( SkillName.Wrestling, 80, 100 );
			SetSkill( SkillName.Magery, 80, 100 );
			SetSkill( SkillName.Tactics, 60, 100 );
			SetSkill( SkillName.EvalInt, 60, 100 );
			SetSkill( SkillName.MagicResist, 60, 100 );
			SetSkill( SkillName.Anatomy, 60, 100 );
			SetSkill( SkillName.Meditation, 60, 100 );

			AddItem( new Sandals() );
			AddItem( new Robe( Utility.RandomYellowHue() ) );

			switch ( Utility.Random( 4 ) )
			{
				case 0: AddItem( new LongHair( Utility.RandomHairHue() ) ); break;
				case 1: AddItem( new ShortHair( Utility.RandomHairHue() ) ); break;
				case 2: AddItem( new PonyTail( Utility.RandomHairHue() ) ); break;
				case 3: AddItem( new TwoPigTails( Utility.RandomHairHue() ) ); break;
			}

			PackItem( new Gold( 100, 250 ) );
			PackItem( new Bandage( Utility.RandomMinMax( 5, 10 ) ) );
			PackItem( new HealPotion() );
			PackItem( new CurePotion() );
		}

		public virtual bool CheckResurrect( Mobile m )
		{
			return true;
		}

		private DateTime m_NextResurrect;
		private static TimeSpan ResurrectDelay = TimeSpan.FromSeconds( 2.0 );

		public override void OnMovement( Mobile m )
		{
			if ( !m.Frozen && !m.Alive && DateTime.Now >= m_NextResurrect && m.InRange( this, 6 ) && InLOS( m ) )
			{
				m_NextResurrect = DateTime.Now + ResurrectDelay;

				if ( m.Map == null || !m.Map.CanFit( m.Location, 16, false, false ) )
				{
					m.SendLocalizedMessage( 502391 ); // Thou can not be resurrected there!
				}
				else if ( CheckResurrect( m ) )
				{
					Direction = GetDirectionTo( m );
					Say( 501224 ); // Thou hast strayed from the path of virtue, but thou still deservest a second chance.

					m.PlaySound( 0x214 );
					Effects.SendTargetEffect( m, 0x376A, 16 );

					m.SendGump( new ResurrectGump( m, ResurrectMessage.Healer ) );
				}
			}
		}

		public BaseHealer( Serial serial ) : base( serial )
		{
		}

		public override void Serialize( GenericWriter writer )
		{
			base.Serialize( writer );

			writer.Write( (int) 0 ); // version
		}

		public override void Deserialize( GenericReader reader )
		{
			base.Deserialize( reader );

			int version = reader.ReadInt();
		}
	}
}