using System; 
using System.Collections; 
using Server.Items; 
using Server.Spells; 
using Server.Spells.First; 
using Server.Spells.Second; 
using Server.Spells.Third; 
using Server.Spells.Fourth; 
using Server.Spells.Fifth; 
using Server.Spells.Sixth; 
using Server.Spells.Seventh; 
using Server.Targeting; 
using Server.Misc; 
using Server.Network; 

namespace Server.Mobiles 
{ 
	[CorpseName( "an ethereal warrior corpse" )] 
	public class EtherealWarrior : BaseCreature 
	{ 
		[Constructable] 
		public EtherealWarrior() : base( AIType.AI_Mage, FightMode.Agressor, 10, 1, 0.2, 0.4 ) 
		{ 
			Body = 123; 
			Name = "an ethereal warrior";

			SetStr( 514, 760 ); 
			SetDex( 186, 240 ); 
			SetInt( 370, 443 ); 
			SetSkill( SkillName.Wrestling, 98, 100 ); 
			SetSkill( SkillName.Tactics, 91, 99 ); 
			SetSkill( SkillName.MagicResist, 90, 99 ); 
			SetSkill( SkillName.Anatomy, 50, 75 );
			SetSkill( SkillName.Magery, 99, 100 ); 
			SetSkill( SkillName.EvalInt, 91, 100 ); 
			SetSkill( SkillName.Meditation, 92, 100 ); 

			VirtualArmor = Utility.RandomMinMax( 102, 120 ); 
			SetFameLevel( 4 ); 
			SetKarmaLevel( -4 ); 

			switch ( Utility.Random( 9 )) 
			{ 
				case 0: PackItem( new Amber( 2 ) ); break; 
				case 1: PackItem( new Amethyst( 2 ) ); break; 
				case 2: PackItem( new Citrine( 2 ) ); break; 
				case 3: PackItem( new Diamond( 2 ) ); break; 
				case 4: PackItem( new Emerald( 2 ) ); break; 
				case 5: PackItem( new Ruby( 2 ) ); break; 
				case 6: PackItem( new Sapphire( 2 ) ); break; 
				case 7: PackItem( new StarSapphire( 2 ) ); break; 
				case 8: PackItem( new Tourmaline( 2 ) ); break; 
			} 
          
			PackItem( new Gold( 400, 700 )); 
			PackItem( new Feather( 100 ) );
		} 

		public override int GetAngerSound()
		{
			return 0x2F8;
		}

		public override int GetIdleSound()
		{
			return 0x2F8;
		}

		public override int GetAttackSound()
		{
			return Utility.Random( 0x2F5, 2 );
		}

		public override int GetHurtSound()
		{
			return 0x2F9;
		}

		public override int GetDeathSound()
		{
			return 0x2F7;
		}

		public override void OnGaveMeleeAttack( Mobile defender )
		{
			defender.Damage( Utility.Random( 10, 10 ) );
			defender.Stam -= Utility.Random( 10, 10 );
			defender.Mana -= Utility.Random( 10, 10 );
		}

		public override void OnGotMeleeAttack( Mobile attacker )
		{
			attacker.Damage( Utility.Random( 10, 10 ) );
			attacker.Stam -= Utility.Random( 10, 10 );
			attacker.Mana -= Utility.Random( 10, 10 );
		}

		public EtherealWarrior( Serial serial ) : base( serial ) 
		{ 
		} 

		public override void Serialize( GenericWriter writer ) 
		{ 
			base.Serialize( writer ); 
			writer.Write( (int) 0 ); 
		} 

		public override void Deserialize( GenericReader reader ) 
		{ 
			base.Deserialize( reader ); 
			int version = reader.ReadInt(); 
		} 
	} 
}