using System;
using System.Collections;
using Server;
using Server.Items;
using Server.Spells;
using Server.GenerateRandomMagicItems;

namespace Server.Mobiles
{
	public class Rikktor : BaseChampion
	{
		[Constructable]
		public Rikktor() : base( AIType.AI_Melee )
		{
			Body = 172;
			Name = "Rikktor";

			SetFameLevel( 5 );
			SetKarmaLevel( 5 );

			SetStr( 745, 810 );
			SetDex( 490, 500 );
			SetInt( 60,  75 );

			VirtualArmor = 130;

			SetSkill( SkillName.Wrestling, 10, 10 ); // 10 wrestling? stratics say so..
			SetSkill( SkillName.Tactics, 100, 100 );
			SetSkill( SkillName.MagicResist, 148, 157 );
			SetSkill( SkillName.Anatomy, 100, 100 );

			PackItem( new Gold( 4000, 5000 ) );

			PackItem( RandomMagicItem.RandomMagicWeapon( (BaseWeapon)RandomMagicItem.RandomWeapon, 3, 5 ) );
			PackItem( RandomMagicItem.RandomMagicWeapon( (BaseWeapon)RandomMagicItem.RandomWeapon, 5, 5 ) );
		}

		[CommandProperty( AccessLevel.GameMaster )]
		public override int HitsMax{ get{ return 5000; } }

		public override void OnGaveMeleeAttack( Mobile defender )
		{
			if ( 0.1 >= Utility.RandomDouble() )
				Earthquake();
		}

		public void Earthquake()
		{
			Map map = this.Map;

			if ( map == null )
				return;

			ArrayList targets = new ArrayList();

			IPooledEnumerable eable = map.GetMobilesInRange( this.Location, 8 );

			foreach ( Mobile m in eable )
			{
				if ( m == this || !CanBeHarmful( m ) )
					continue;

				if ( m is BaseCreature && (((BaseCreature)m).Controled || ((BaseCreature)m).Summoned || ((BaseCreature)m).Team != this.Team) )
					targets.Add( m );
				else if ( m.Player )
					targets.Add( m );
			}

			eable.Free();

			PlaySound( 0x2F3 );

			for ( int i = 0; i < targets.Count; ++i )
			{
				Mobile m = (Mobile)targets[i];

				double damage = m.Hits * 0.6;

				if ( damage < 10.0 )
					damage = 10.0;
				else if ( damage > 75.0 )
					damage = 75.0;

				DoHarmful( m );

				m.Damage( (int) damage );

				if ( m.Alive && m.Body.IsHuman && !m.Mounted )
					m.Animate( 20, 7, 1, true, false, 0 ); // take hit
			}
		}

		public override int GetAngerSound()
		{
			return Utility.Random( 0x2CE, 2 );
		}

		public override int GetIdleSound()
		{
			return 0x2D2;
		}

		public override int GetAttackSound()
		{
			return Utility.Random( 0x2C7, 5 );
		}

		public override int GetHurtSound()
		{
			return 0x2D1;
		}

		public override int GetDeathSound()
		{
			return 0x2CC;
		}

		public Rikktor( Serial serial ) : base( serial )
		{
		}

		public override void Serialize( GenericWriter writer )
		{
			base.Serialize( writer );

			writer.Write( (int) 0 ); // version
		}

		public override void Deserialize( GenericReader reader )
		{
			base.Deserialize( reader );

			int version = reader.ReadInt();
		}
	}
}