using System;
using Server;
using Server.Items;
using Server.Engines.Harvest;

namespace Server.Regions
{
	public class FeluccaMine : Region
	{
		private int m_ExtractCount;
		private int m_ExtractMax;
		private Type m_OreType;

		public static void Initialize()
		{
			Region.AddRegion( new FeluccaMine( "Minoc Mine" ) );
			Region.AddRegion( new FeluccaMine( "Minoc Cave 1" ) );
			Region.AddRegion( new FeluccaMine( "Minoc Cave 2" ) );
			Region.AddRegion( new FeluccaMine( "Minoc Cave 3" ) );
			Region.AddRegion( new FeluccaMine( "Mt Kendall" ) );
			Region.AddRegion( new FeluccaMine( "Cave 1" ) );
			Region.AddRegion( new FeluccaMine( "Cave 2" ) );
			Region.AddRegion( new FeluccaMine( "Cave 3" ) );
			Region.AddRegion( new FeluccaMine( "Cave 4" ) );
			Region.AddRegion( new FeluccaMine( "Britain Mine 1" ) );
			Region.AddRegion( new FeluccaMine( "Britain Mine 2" ) );
			Region.AddRegion( new FeluccaMine( "Avatar Isle Cave" ) );
			Region.AddRegion( new FeluccaMine( "Ice Isle Cave 1" ) );
			Region.AddRegion( new FeluccaMine( "Ice Isle Cave 2" ) );
			Region.AddRegion( new FeluccaMine( "Yew Cave" ) );
			Region.AddRegion( new FeluccaMine( "North Territory Cave" ) );
			Region.AddRegion( new FeluccaMine( "North Territory Mine 1" ) );
			Region.AddRegion( new FeluccaMine( "North Territory Mine 2" ) );
			Region.AddRegion( new FeluccaMine( "Covetous Mine" ) );
		}

		public FeluccaMine( string name ) : base( "", name, Map.Felucca )
		{
			m_OreType = typeof( IronOre );
			ChangeOreType();
		}

		public void ChangeOreType()
		{
			if ( m_OreType == typeof( IronOre ) )
			{
				int random = Utility.Random( DefMining.HarvestSystem.HarvestResDefs.Count );
				m_OreType = DefMining.HarvestSystem.HarvestResDefs.GetAt(random).ResType;
			}
			else
			{
				m_OreType = typeof( IronOre );
			}

			m_ExtractCount = 0;
			m_ExtractMax = Utility.Random( 10, 30 );
		}

		public override Type GetResource( Type type )
		{
			m_ExtractCount++;

			if ( m_ExtractCount > m_ExtractMax )
				ChangeOreType();

			if ( type == typeof( IronOre ) )
			{
				// 50% chance of getting the colored ore
				if ( Utility.Random( 2 ) == 0 )				
					return m_OreType;
			}

			// Return the default base value
			return base.GetResource( type );
		}

		public override void OnEnter( Mobile from )
		{
			// Disable the default OnEnter message
		}

		public override void OnExit( Mobile from )
		{
			// Disable the default OnExit message
		}
	}
}